@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import argparse
 import datetime
 import os
@@ -11,11 +13,11 @@ from typing import List
 if os.environ.get("MENT_DIR") is None:
     BASE_DIR = Path.home() / "ment_dir"
 else:
-    BASE_DIR = Path(os.environ.get("MENT_DIR"))
+    BASE_DIR = Path(os.environ.get("MENT_DIR"))  # type:ignore
 if os.environ.get("MENT_EDITOR") is None:
     MENT_EDITOR = "vim"
 else:
-    MENT_EDITOR = os.environ.get("MENT_EDITOR")
+    MENT_EDITOR = os.environ.get("MENT_EDITOR")  # type:ignore
 
 
 def get_args():
@@ -26,9 +28,7 @@ def get_args():
     parser_list = subparsers.add_parser("list", help="list names of tags")
     parser_list.set_defaults(handler=command_list)
 
-    parser_synthe = subparsers.add_parser(
-        "synthe", help="synthesize from daily.md files by tag"
-    )
+    parser_synthe = subparsers.add_parser("synthe", help="synthesize from daily.md files by tag")
     parser_synthe.add_argument(
         "tag",
         type=str,
@@ -36,20 +36,22 @@ def get_args():
     )
     parser_synthe.set_defaults(handler=command_synthe)
 
-    parser_week = subparsers.add_parser(
-        "week", help="output notes of recent 7 days")
+    parser_week = subparsers.add_parser("week", help="output notes of recent 7 days")
     parser_week.set_defaults(handler=command_week)
 
-    parser_read = subparsers.add_parser(
-        "read", help="open tag-synthesized file for reading"
-    )
+    parser_read = subparsers.add_parser("read", help="open tag-synthesized file for reading")
     parser_read.add_argument(
         "tag",
         type=str,
         help="open tag-synthesized file for reading",
     )
     parser_read.set_defaults(handler=command_read)
+
+    parser_list = subparsers.add_parser("update", help="update all synthesized documents")
+    parser_list.set_defaults(handler=command_update)
+
     args = parser.parse_args()
+
     return args
 
 
@@ -58,6 +60,24 @@ def command_list(args):
     exit()
 
 
+def command_update(args):
+    """
+    合成ファイルの一括更新
+    ```
+    m week
+    m synthe {any tag}
+    ```
+    """
+    combine_recent_docs_to_one(BASE_DIR)
+    for dst_dir in (BASE_DIR / "synthe").iterdir():
+        tag = dst_dir.stem
+        # week,externalはtagとして扱えない
+        if tag == "week" or tag == "external":
+            continue
+        synthesize_by_tag(dst_dir.stem, BASE_DIR, dst_dir)
+    exit()
+
+
 def command_synthe(args):
     tag = args.tag
     dst_dir: Path = BASE_DIR / "synthe" / tag
@@ -71,11 +91,10 @@ def command_read(args):
     tag = args.tag
     read_file_path = Path(BASE_DIR) / "synthe" / tag / f"synthe_{tag}.md"
     if not read_file_path.exists():
-        raise FileNotFoundError(
-            f"Please run `m synthe {tag}` or `m week` before read command"
-        )
+        raise FileNotFoundError(f"Please run `m synthe {tag}` or `m week` before read command")
     else:
         subprocess.run([MENT_EDITOR, read_file_path])
+        exit()
 
 
 def command_week(args):
@@ -103,19 +122,22 @@ def list_tags(src_dir):
     日付ごとにタグを列挙
     """
     src_mkd_dir = Path(src_dir)
-    mkd_dir_paths = [
-        mkd_dirs for mkd_dirs in src_mkd_dir.iterdir() if mkd_dirs.stem != "synthe"
-    ]
+    mkd_dir_paths = [mkd_dirs for mkd_dirs in src_mkd_dir.iterdir() if mkd_dirs.stem != "synthe"]
     # 時系列順に眺めていきたい
     tag_cnt = Counter()
     mkd_dir_paths.sort()
     for src_mkd_dir in mkd_dir_paths:
-        diary_path = src_mkd_dir / "diary.md"
+        file_name = src_mkd_dir.name + ".md"
+        diary_path = src_mkd_dir / file_name
+        if not diary_path.exists():
+            diary_path = src_mkd_dir / "diary.md"
+
         if diary_path.exists():
             tags = _extract_tags(diary_path)
-            print(f"\033[32m{src_mkd_dir}\33[0m", tags)
+            print(f"\033[32m{src_mkd_dir.stem}\33[0m")
+            print(*tags, sep="\n")
             tag_cnt += Counter(tags)
-    print(tag_cnt)
+    # print(tag_cnt)
 
 
 def extract_content_for_tag_from_mkd(mkd_path: Path, query_tag: str) -> List[str]:
@@ -147,7 +169,7 @@ def extract_content_for_tag_from_mkd(mkd_path: Path, query_tag: str) -> List[str
     return contents_lines
 
 
-def make_header(diary_path: Path) -> List[str]:
+def make_header(diary_path: Path) -> list[str]:
     header = [
         "# " + diary_path.parent.name + "\n\n",
     ]  # 抽出元ファイル
@@ -161,11 +183,10 @@ def combine_recent_docs_to_one(base_dir: Path, day_num=7):
     output_file = base_dir / "synthe/week/synthe_week.md"
     with open(output_file, "w") as f:
         for delta_day in range(day_num - 1, -1, -1):
-            diary_path = (
-                base_dir
-                / str(datetime.date.today() - datetime.timedelta(delta_day))
-                / "diary.md"
-            )
+            date = str(datetime.date.today() - datetime.timedelta(delta_day))
+            diary_path = base_dir / date / f"{date}.md"
+            if not diary_path.exists():
+                diary_path = base_dir / date / "diary.md"
             if diary_path.exists():
                 with open(diary_path, "r") as f2:
                     mkd_content = f2.read()
@@ -192,9 +213,7 @@ def synthesize_by_tag(tag: str, src_dir: Path, dst_dir: Path):
         src_dir:統合されるマークダウンを格納したディレクトリ群の親ディレクトリ
         dst_dir:生成するマークダウンの場所
     """
-    mkd_dir_paths = [
-        mkd_dir for mkd_dir in src_dir.iterdir() if mkd_dir.stem != "synthe"
-    ]
+    mkd_dir_paths: list[Path] = [mkd_dir for mkd_dir in src_dir.iterdir() if mkd_dir.stem != "synthe"]
     # 時系列順に眺めていきたい
     mkd_dir_paths.sort()
     p = Path(dst_dir)
@@ -203,7 +222,9 @@ def synthesize_by_tag(tag: str, src_dir: Path, dst_dir: Path):
     print(f"Extracting tag `{tag}` from")
     with open(output_file, "w") as f:
         for src_mkd_dir in mkd_dir_paths:
-            diary_path = Path(src_mkd_dir) / "diary.md"
+            diary_path = Path(src_mkd_dir) / f"{src_mkd_dir.name}.md"
+            if not diary_path.exists():
+                diary_path = Path(src_mkd_dir) / "diary.md"
             if diary_path.exists():
                 header = make_header(diary_path)
                 clines = extract_content_for_tag_from_mkd(diary_path, tag)
@@ -232,8 +253,7 @@ def main():
 
     YYYY_MM_DD = str(datetime.date.today())
 
-    title = "diary"
-    file_name = title + ".md"
+    file_name = YYYY_MM_DD + ".md"
     Path(BASE_DIR / YYYY_MM_DD).mkdir(exist_ok=True)
     file_path = BASE_DIR / YYYY_MM_DD / file_name
 
